﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;

namespace WpfApplication1
{
	public class Cluster : IPath
	{
		public Cluster(string name)
		{
			this.Name = name;
			this.Children = new ObservableCollection<CustomView>();
			this.Children.CollectionChanged += new System.Collections.Specialized.NotifyCollectionChangedEventHandler(Children_CollectionChanged);
		}

		private void Children_CollectionChanged(object sender, System.Collections.Specialized.NotifyCollectionChangedEventArgs e)
		{
			if (e.Action == System.Collections.Specialized.NotifyCollectionChangedAction.Add)
			{
				var item = e.NewItems[0] as IPath;
				item.Parent = this;
			}
		}

		/// <summary>
		/// Gets or sets the name of the node.
		/// </summary>
		public string Name { get; set; }
		
		/// <summary>
		/// Gets or sets the children of the node.
		/// </summary>
		public ObservableCollection<CustomView> Children { get; set; }
		
		/// <summary>
		/// Gets or sets the parent of the node. This property is used for building the full path to the node.
		/// </summary>
		public IPath Parent
		{
			get;
			set;
		}

		public override string ToString()
		{
			// The TreeView builds the path of items by calling the ToString()
			// method, we need to return something unique here.
			return this.Name;
		}

		/// <summary>
		/// Gets the full path to the node. Use by the treeview to expand to this node.
		/// </summary>
		public string GetFullPath()
		{
			if (this.Parent != null)
			{
				return this.Parent.GetFullPath() + "|" + this.ToString();
			}
			return this.ToString();
		}
	}
}
